@@ -1,5 +1,7 @@
 """
-Main interface for cloudsearchdomain service type definitions.
+Type annotations for cloudsearchdomain service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/type_defs.html)
 
 Usage::
 
@@ -25,22 +27,28 @@ __all__ = (
     "FieldStatsTypeDef",
     "HitTypeDef",
     "HitsTypeDef",
+    "SearchResponseTypeDef",
     "SearchStatusTypeDef",
     "SuggestModelTypeDef",
+    "SuggestResponseTypeDef",
     "SuggestStatusTypeDef",
     "SuggestionMatchTypeDef",
-    "SearchResponseTypeDef",
-    "SuggestResponseTypeDef",
     "UploadDocumentsResponseTypeDef",
 )
 
-BucketInfoTypeDef = TypedDict("BucketInfoTypeDef", {"buckets": List["BucketTypeDef"]}, total=False)
 
-BucketTypeDef = TypedDict("BucketTypeDef", {"value": str, "count": int}, total=False)
+class BucketInfoTypeDef(TypedDict, total=False):
+    buckets: List["BucketTypeDef"]
+
+
+class BucketTypeDef(TypedDict, total=False):
+    value: str
+    count: int
+
+
+class DocumentServiceWarningTypeDef(TypedDict, total=False):
+    message: str
 
-DocumentServiceWarningTypeDef = TypedDict(
-    "DocumentServiceWarningTypeDef", {"message": str}, total=False
-)
 
 FieldStatsTypeDef = TypedDict(
     "FieldStatsTypeDef",
@@ -68,45 +76,49 @@ HitTypeDef = TypedDict(
     total=False,
 )
 
-HitsTypeDef = TypedDict(
-    "HitsTypeDef",
-    {"found": int, "start": int, "cursor": str, "hit": List["HitTypeDef"]},
-    total=False,
-)
 
-SearchStatusTypeDef = TypedDict("SearchStatusTypeDef", {"timems": int, "rid": str}, total=False)
+class HitsTypeDef(TypedDict, total=False):
+    found: int
+    start: int
+    cursor: str
+    hit: List["HitTypeDef"]
 
-SuggestModelTypeDef = TypedDict(
-    "SuggestModelTypeDef",
-    {"query": str, "found": int, "suggestions": List["SuggestionMatchTypeDef"]},
-    total=False,
-)
 
-SuggestStatusTypeDef = TypedDict("SuggestStatusTypeDef", {"timems": int, "rid": str}, total=False)
+class SearchResponseTypeDef(TypedDict, total=False):
+    status: "SearchStatusTypeDef"
+    hits: "HitsTypeDef"
+    facets: Dict[str, "BucketInfoTypeDef"]
+    stats: Dict[str, "FieldStatsTypeDef"]
+
+
+class SearchStatusTypeDef(TypedDict, total=False):
+    timems: int
+    rid: str
+
+
+class SuggestModelTypeDef(TypedDict, total=False):
+    query: str
+    found: int
+    suggestions: List["SuggestionMatchTypeDef"]
+
+
+class SuggestResponseTypeDef(TypedDict, total=False):
+    status: "SuggestStatusTypeDef"
+    suggest: "SuggestModelTypeDef"
+
+
+class SuggestStatusTypeDef(TypedDict, total=False):
+    timems: int
+    rid: str
+
 
 SuggestionMatchTypeDef = TypedDict(
     "SuggestionMatchTypeDef", {"suggestion": str, "score": int, "id": str}, total=False
 )
 
-SearchResponseTypeDef = TypedDict(
-    "SearchResponseTypeDef",
-    {
-        "status": "SearchStatusTypeDef",
-        "hits": "HitsTypeDef",
-        "facets": Dict[str, "BucketInfoTypeDef"],
-        "stats": Dict[str, "FieldStatsTypeDef"],
-    },
-    total=False,
-)
 
-SuggestResponseTypeDef = TypedDict(
-    "SuggestResponseTypeDef",
-    {"status": "SuggestStatusTypeDef", "suggest": "SuggestModelTypeDef"},
-    total=False,
-)
-
-UploadDocumentsResponseTypeDef = TypedDict(
-    "UploadDocumentsResponseTypeDef",
-    {"status": str, "adds": int, "deletes": int, "warnings": List["DocumentServiceWarningTypeDef"]},
-    total=False,
-)
+class UploadDocumentsResponseTypeDef(TypedDict, total=False):
+    status: str
+    adds: int
+    deletes: int
+    warnings: List["DocumentServiceWarningTypeDef"]
